{%- set author = authors | first -%}

## {{ role.name }}

{% if ansigenome_info.travis is defined and ansigenome_info.travis %}[![Travis CI](https://secure.travis-ci.org/{{ role.slug }}.png)](http://travis-ci.org/{{ role.slug }}){% endif %} {% if ansigenome_info.galaxy_id is defined and ansigenome_info.galaxy_id %}[![Ansible Galaxy](http://img.shields.io/badge/galaxy-{{ role.galaxy_name }}-660198.svg)](https://galaxy.ansible.com/list#/roles/{{ ansigenome_info.galaxy_id }}){% endif %}{% if galaxy_info.platforms is defined and galaxy_info.platforms %}[![Platforms](http://img.shields.io/badge/platforms-{{ galaxy_info.platforms | map(attribute='name') | sort | join('%20|%20') | lower }}-lightgrey.svg)](#){% endif %}
{% if ansigenome_info.beta is defined and ansigenome_info.beta %}
### Warning, this is a BETA role

This role has been marked by the author as a beta role, which means that it
might be significantly changed in the future. Be careful while using this role
in a production environment.

***{% endif %}{% if ansigenome_info.synopsis is defined %}
{{ ansigenome_info.synopsis | trim }}{% endif %}

{% if ansigenome_info.galaxy_id is defined and ansigenome_info.galaxy_id %}
### Installation

This role requires at least Ansible{% if galaxy_info.min_ansible_version is defined and galaxy_info.min_ansible_version %} `v{{ galaxy_info.min_ansible_version }}`{% endif %}. To install it, run:

    ansible-galaxy install {{ role.galaxy_name }}

{% endif %}
{% if ansigenome_info.quick_start is defined and ansigenome_info.quick_start %}

### Quick start

{{ ansigenome_info.quick_start | trim | indent(4, true) }}{% endif %}
{% if dependencies is defined and dependencies -%}

### Role dependencies
{% for dependency in dependencies %}
- `{{ dependency.role | trim }}`{% endfor %}
{% endif %}
{% if ansigenome_info.defaults is defined and ansigenome_info.defaults %}

### Role variables

List of default variables available in the inventory:

{{ ansigenome_info.defaults | trim | indent(4, true) }}
{% endif %}
{% if ansigenome_info.facts is defined and ansigenome_info.facts %}

List of internal variables used by the role:

{{ ansigenome_info.facts | trim | indent(4, true) }}{% endif %}
{% if ansigenome_info.usage is defined and ansigenome_info.usage %}

### Detailed usage guide

{{ ansigenome_info.usage | trim }}{% endif %}
{% if ansigenome_info.custom is defined and ansigenome_info.custom %}

{{ ansigenome_info.custom | trim }}{% endif %}
### Authors and license

`{{ role.name }}` role was written by:
{% for credit in authors %}
- {% if credit.url is defined and credit.url %}[{% endif %}{{ credit.name }}{% if credit.url is defined and credit.url %}]({{ credit.url }}){% endif %}{% if credit.email is defined and credit.email %} | [e-mail](mailto:{{ credit.email }}){% endif %}{% if credit.twitter is defined and credit.twitter %} | [Twitter](https://twitter.com/{{ credit.twitter }}){% endif %}{% if credit.github is defined and credit.github %} | [GitHub](https://github.com/{{ credit.github }}){% endif %}
{% endfor %}
License: [{{ license.type | trim }}]({{ license.url | trim }})

***

README generated by [ansigenome](https://github.com/nickjj/ansigenome/).

